@@ -49,8 +49,9 @@ public:
 };
 
 #ifdef  _MSWINDOWS_
-extern LONG buffer_framing = 120;   // millisec
-extern LONG buffer_count = 8;
+extern LONG buffer_framing, buffer_count;
+LONG buffer_framing = 120;   // millisec
+LONG buffer_count = 8;
 #endif
 
 static class AudioRegistry registry;
