@@ -17,7 +17,7 @@
 // along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <ucommon/ucommon.h>
-#include <config.h>
+#include <ccaudio2-config.h>
 #include <math.h>
 #ifdef  HAVE_ENDIAN_H
 #include <endian.h>
@@ -111,7 +111,7 @@ public:
 
 W32AudioDevice *W32AudioDevice::devices[MAX_DEVICES + 1];
 
-static void CALLBACK playProc(HWAVEOUT hPlay, UINT msg, DWORD instance, DWORD p1, DWORD p2)
+void CALLBACK playProc(HWAVEOUT hPlay, UINT msg, DWORD instance, DWORD p1, DWORD p2)
 {
     W32AudioDevice *dev = W32AudioDevice::devices[instance];
     if(msg != WOM_DONE)
@@ -222,7 +222,7 @@ bool W32AudioDevice::setAudio(Rate rate, bool stereo, timeout_t framing)
     info.bitrate = rate * 16 * channels;
     info.order = __BYTE_ORDER;
     info.format = raw;
-    info.annotation = "Microsoft Windows";
+    info.annotation = (char *)"Microsoft Windows";
     info.framecount = bufsize / 2 / channels;
     info.framesize = bufsize;
     info.framing = (info.framecount * 1000l) / info.rate;
@@ -245,10 +245,6 @@ bool W32AudioDevice::setAudio(Rate rate, bool stereo, timeout_t framing)
 
     sem = new W32Semaphore(bufcount);
 
-#if !defined(_MSC_VER) || _MSC_VER < 1300
-#define DWORD_PTR DWORD
-#endif
-
     if(waveOutOpen(&hPlay, WAVE_MAPPER, &wfx, (DWORD_PTR)&playProc, (DWORD)devid, CALLBACK_FUNCTION) != MMSYSERR_NOERROR)
         return false;
 
