@@ -17,7 +17,7 @@
 // along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <ccaudio2.h>
-#include <config.h>
+#include <ccaudio2-config.h>
 #ifdef  HAVE_ENDIAN_H
 #include <endian.h>
 #endif
@@ -181,8 +181,8 @@ void AudioBuild::copyConvert(AudioStream &input, AudioStream &output)
         else
             npages = output.bufStereo(source, copied);
 
-        // if(!npages)
-        //  break;
+        if(!npages)
+            break;
     }
 
     delete[] buffer;
@@ -199,14 +199,14 @@ void AudioBuild::copyDirect(AudioStream &input, AudioStream &output)
     unsigned bufsize;
     Encoded buffer;
     Info from, to;
-    bool endian = false;
+//    bool endian = false;
     ssize_t status = 1;
 
     input.getInfo(&from);
     output.getInfo(&to);
 
-    if(to.order && from.order && to.order != from.order && is_linear(from.encoding))
-        endian = true;
+//    if(to.order && from.order && to.order != from.order && is_linear(from.encoding))
+//        endian = true;
 
     bufsize = from.framesize;
     buffer = new unsigned char[bufsize];
@@ -401,12 +401,12 @@ skip:
         framing = 20;
 
     while(*argv) {
-        if(!fsys::isfile(*argv)) {
+        if(!fsys::is_file(*argv)) {
             printf("%s: %s\n",
                 fname(*(argv++)), _TEXT("invalid"));
             continue;
         }
-        if(fsys::access(*argv, R_OK)) {
+        if(!fsys::is_readable(*argv)) {
             printf("%s: %s\n",
                 fname(*(argv++)), _TEXT("inaccessable"));
             continue;
@@ -513,7 +513,7 @@ static void info(char **argv)
     Audio::Info info;
     const char *fn;
     timeout_t framing = 0;
-    unsigned long size, end;
+    unsigned long end;
     unsigned long minutes, seconds, subsec, scale;
 
     fn = *argv;
@@ -530,12 +530,12 @@ static void info(char **argv)
     }
 
     while(*argv) {
-        if(!fsys::isfile(*argv)) {
+        if(!fsys::is_file(*argv)) {
             printf("audiotool: %s: %s\n",
                 fname(*(argv++)), _TEXT("invalid"));
             continue;
         }
-        if(fsys::access(*argv, R_OK)) {
+        if(fsys::is_readable(*argv)) {
             printf("audiotool: %s: %s\n",
                 fname(*(argv++)), _TEXT("inaccessable"));
             continue;
@@ -543,7 +543,7 @@ static void info(char **argv)
         au.open(*argv, Audio::modeInfo, framing);
         au.getInfo(&info);
         au.setPosition();
-        size = end = au.getPosition();
+        end = au.getPosition();
         printf("%s\n", fname(*(argv++)));
         fn = Audio::getMIME(info);
         if(!fn)
@@ -682,12 +682,12 @@ skip:
         framing = 20;
 
     while(*argv) {
-        if(!fsys::isfile(*argv)) {
+        if(!fsys::is_file(*argv)) {
             printf("%s: %s\n",
                 *(argv++), _TEXT("invalid"));
             continue;
         }
-        if(fsys::access(*argv, R_OK)) {
+        if(fsys::is_readable(*argv)) {
             printf("%s: %s\n",
                 *(argv++), _TEXT("inaccessable"));
             continue;
@@ -805,7 +805,6 @@ static void trim(char **argv)
     int rtn;
     unsigned char *buffer;
     Audio::Linear samples = NULL;
-    Audio::Level max;
     unsigned long sum;
     unsigned long count;
     char target[256];
@@ -881,12 +880,12 @@ skip:
         framing = 20;
 
     while(*argv) {
-        if(!fsys::isfile(*argv)) {
+        if(!fsys::is_file(*argv)) {
             printf("%s: %s\n",
                 *(argv++), _TEXT("invalid"));
             continue;
         }
-        if(fsys::access(*argv, R_OK)) {
+        if(fsys::is_readable(*argv)) {
             printf("%s: %s\n",
                 *(argv++), _TEXT("inaccessable"));
             continue;
@@ -905,7 +904,6 @@ skip:
 
         buffer = new unsigned char[info.framesize];
 
-        max = 0;
         sum = 0;
         count = 0;
 
@@ -925,7 +923,6 @@ skip:
         if(!silence && count)
             silence = (Audio::Level)(((sum / count) * 2) / 3);
 
-        max = 0;
         sum = 0;
         count = 0;
 
@@ -1138,7 +1135,7 @@ static void packetdump(char **argv)
     buffer = new unsigned char[Audio::maxFramesize(info)];
 
     while((count = packetfile.getPacket(buffer)) > 0)
-        printf("-- %ld\n", count);
+        printf("-- %ld\n", (long)count);
 
     delete[] buffer;
     packetfile.close();
@@ -1216,7 +1213,7 @@ static void build(char **argv)
     AudioBuild input;
     AudioStream output;
     Audio::Info info, make;
-    const char *target;
+    const char *target = NULL;
     char *option;
     char *encoding = NULL;
     Audio::Rate rate = Audio::rateUnknown;
@@ -1328,7 +1325,7 @@ static void append(char **argv)
     AudioBuild input;
     AudioStream output;
     Audio::Info info, make;
-    const char *target;
+    const char *target = NULL;
     char *option;
     char *offset = NULL;
 
